import { createError, getHeader } from "h3";
import { getMultiCacheContext } from "./../../../helpers/server.mjs";
import { useRuntimeConfig } from "#imports";
import serverOptions from "#multi-cache-server-options";
const runtimeConfig = useRuntimeConfig();
const AUTH_HEADER = "x-nuxt-multi-cache-token";
export function getCacheInstance(event) {
  const cacheContext = getMultiCacheContext(event);
  if (!cacheContext) {
    throw createError({
      statusCode: 500,
      statusMessage: "Failed to load cache context."
    });
  }
  const cacheName = event.context.params.cacheName;
  const cache = cacheContext[cacheName];
  if (!cache) {
    throw createError({
      statusCode: 404,
      statusMessage: `The given cache "${cacheName}" is not available.`
    });
  }
  return cache;
}
export async function checkAuth(event, providedRuntimeConfig, providedServerOptions) {
  const { authorizationDisabled, authorizationToken } = (providedRuntimeConfig || runtimeConfig.multiCache).api || {};
  if (authorizationDisabled) {
    return;
  }
  if (authorizationToken) {
    const headerToken = getHeader(event, AUTH_HEADER);
    if (headerToken === authorizationToken) {
      return;
    }
    throw createError({
      statusCode: 401,
      statusMessage: "Unauthorized"
    });
  }
  const authorization = (providedServerOptions || serverOptions).api?.authorization;
  if (!authorization) {
    throw createError({
      statusCode: 500,
      statusMessage: "No authorization configuration option provided."
    });
  }
  const result = await authorization(event);
  if (result) {
    return;
  }
  throw createError({
    statusCode: 401,
    statusMessage: "Unauthorized"
  });
}
